# Step 02: Remediação (SRE)

## Inputs
- Classificação de severidade da triagem
- Serviços afetados

## Expected Outputs
- Runbook executado ou fix aplicado
- Log de ações tomadas

## Quality Gate
- [ ] Ação de remediação executada
- [ ] Log de ações documentado

## Veto Conditions
- Nenhuma ação tomada
